# fcmaes
A Python 3 gradient-free optimization library.

- [README](https://github.com/dietmarwo/fast-cma-es/blob/master/README.adoc)
- [Tutorial](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Tutorial.adoc)
- [Crypto Trading](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/CryptoTrading.adoc)
- [Water Resource Management](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Water.adoc)  
- [Multi-UAV Task Assignment](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/UAV.adoc) 
- [Surrogate](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Surrogate.adoc)
- [Robots and Rovers](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/RobotRover.adoc)
- [CFD](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/FluidDynamics.adoc)
- [Noisy TSP](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/TSP.adoc)
- [Hospital](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Hospital.adoc)
- [JobShop](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/JobShop.adoc)
- [Scheduling](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Scheduling.adoc)
- [MODE](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/MODE.adoc)
- [Multi-Objective](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/MultiObjective.adoc), 
- [MO-DE-NSGAII](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/NSGAII.adoc), 
- [gbea TopTrumps Benchmark](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/TopTrumps.adoc),
- [Pagmo results](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/PAGMO.adoc), 
- [PYKEP Gym Results](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/PYKEP.adoc)
- [Constraints](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Constraints.adoc)
- [Expressions](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Expressions.adoc)
- [ODE](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/ODE.adoc)
- [MINLP](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/MINLP.adoc)
- [HyperParameters](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/HyperparameterOptimization.adoc)
- [Delayed Update](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/DelayedUpdate.adoc)




